CRAIGSLIST = (
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "egypt", "title": "Egypt"},
        "site": {"key": "cairo", "title": "Egypt", "url": "https://cairo.craigslist.org/",},
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "ethiopia", "title": "Ethiopia"},
        "site": {
            "key": "addisababa",
            "title": "Ethiopia",
            "url": "https://addisababa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "ghana", "title": "Ghana"},
        "site": {"key": "accra", "title": "Ghana", "url": "https://accra.craigslist.org/",},
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "kenya", "title": "Kenya"},
        "site": {"key": "kenya", "title": "Kenya", "url": "https://kenya.craigslist.org/",},
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "morocco", "title": "Morocco"},
        "site": {
            "key": "casablanca",
            "title": "Morocco",
            "url": "https://casablanca.craigslist.org/",
        },
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "south_africa", "title": "South Africa"},
        "site": {
            "key": "capetown",
            "title": "Cape Town",
            "url": "https://capetown.craigslist.org/",
        },
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "south_africa", "title": "South Africa"},
        "site": {"key": "durban", "title": "Durban", "url": "https://durban.craigslist.org/",},
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "south_africa", "title": "South Africa"},
        "site": {
            "key": "johannesburg",
            "title": "Johannesburg",
            "url": "https://johannesburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "south_africa", "title": "South Africa"},
        "site": {
            "key": "pretoria",
            "title": "Pretoria",
            "url": "https://pretoria.craigslist.org/",
        },
    },
    {
        "continent": {"key": "africa", "title": "Africa"},
        "country": {"key": "tunisia", "title": "Tunisia"},
        "site": {"key": "tunis", "title": "Tunisia", "url": "https://tunis.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "argentina", "title": "Argentina"},
        "site": {
            "key": "buenosaires",
            "title": "Buenos Aires",
            "url": "https://buenosaires.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "bolivia", "title": "Bolivia"},
        "site": {"key": "lapaz", "title": "Bolivia", "url": "https://lapaz.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "belohorizonte",
            "title": "Belo Horizonte",
            "url": "https://belohorizonte.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "brasilia",
            "title": "Bras\u00edlia",
            "url": "https://brasilia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "curitiba",
            "title": "Curitiba",
            "url": "https://curitiba.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "fortaleza",
            "title": "Fortaleza",
            "url": "https://fortaleza.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "portoalegre",
            "title": "Porto Alegre",
            "url": "https://portoalegre.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {"key": "recife", "title": "Recife", "url": "https://recife.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {"key": "rio", "title": "Rio De Janeiro", "url": "https://rio.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "salvador",
            "title": "Salvador, Bahia",
            "url": "https://salvador.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "brazil", "title": "Brazil"},
        "site": {
            "key": "saopaulo",
            "title": "S\u00e3o Paulo",
            "url": "https://saopaulo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "abbotsford",
            "title": "Fraser Valley, BC",
            "url": "https://abbotsford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "barrie", "title": "Barrie, ON", "url": "https://barrie.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "belleville",
            "title": "Belleville, ON",
            "url": "https://belleville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "brantford",
            "title": "Brantford-Woodstock",
            "url": "https://brantford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "calgary",
            "title": "Calgary, AB",
            "url": "https://calgary.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "cariboo",
            "title": "Cariboo, BC",
            "url": "https://cariboo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "chatham",
            "title": "Chatham-Kent, ON",
            "url": "https://chatham.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "comoxvalley",
            "title": "Comox Valley, BC",
            "url": "https://comoxvalley.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "cornwall",
            "title": "Cornwall, ON",
            "url": "https://cornwall.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "edmonton",
            "title": "Edmonton, AB",
            "url": "https://edmonton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "ftmcmurray",
            "title": "Ft Mcmurray, AB",
            "url": "https://ftmcmurray.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "guelph", "title": "Guelph, ON", "url": "https://guelph.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "halifax",
            "title": "Halifax, NS",
            "url": "https://halifax.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "hamilton",
            "title": "Hamilton-Burlington",
            "url": "https://hamilton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "hat", "title": "Medicine Hat, AB", "url": "https://hat.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "kamloops",
            "title": "Kamloops, BC",
            "url": "https://kamloops.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "kelowna",
            "title": "Kelowna / Okanagan",
            "url": "https://kelowna.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "kingston",
            "title": "Kingston, ON",
            "url": "https://kingston.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "kitchener",
            "title": "Kitchener-Waterloo-Cambridge",
            "url": "https://kitchener.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "kootenays",
            "title": "Kootenays, BC",
            "url": "https://kootenays.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "lethbridge",
            "title": "Lethbridge, AB",
            "url": "https://lethbridge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "londonon",
            "title": "London, ON",
            "url": "https://londonon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "montreal",
            "title": "Montreal, QC",
            "url": "https://montreal.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "nanaimo",
            "title": "Nanaimo, BC",
            "url": "https://nanaimo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "newbrunswick",
            "title": "New Brunswick",
            "url": "https://newbrunswick.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "newfoundland",
            "title": "St John'S, NL",
            "url": "https://newfoundland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "niagara",
            "title": "Niagara Region",
            "url": "https://niagara.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "ottawa",
            "title": "Ottawa-Hull-Gatineau",
            "url": "https://ottawa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "owensound",
            "title": "Owen Sound, ON",
            "url": "https://owensound.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "peace",
            "title": "Peace River Country",
            "url": "https://peace.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "pei",
            "title": "Prince Edward Island",
            "url": "https://pei.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "peterborough",
            "title": "Peterborough, ON",
            "url": "https://peterborough.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "princegeorge",
            "title": "Prince George, BC",
            "url": "https://princegeorge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "quebec",
            "title": "Qu\u00e9bec (Ville)",
            "url": "https://quebec.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "reddeer",
            "title": "Red Deer, AB",
            "url": "https://reddeer.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "regina", "title": "Regina, SK", "url": "https://regina.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "saguenay",
            "title": "Saguenay, QC",
            "url": "https://saguenay.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "sarnia", "title": "Sarnia, ON", "url": "https://sarnia.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "saskatoon",
            "title": "Saskatoon, SK",
            "url": "https://saskatoon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "sherbrooke",
            "title": "Sherbrooke, QC",
            "url": "https://sherbrooke.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "skeena",
            "title": "Skeena-Bulkley",
            "url": "https://skeena.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "soo",
            "title": "Sault Ste Marie, ON",
            "url": "https://soo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "sudbury",
            "title": "Sudbury, ON",
            "url": "https://sudbury.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "sunshine",
            "title": "Sunshine Coast, BC",
            "url": "https://sunshine.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "territories",
            "title": "Territories",
            "url": "https://territories.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "thunderbay",
            "title": "Thunder Bay, ON",
            "url": "https://thunderbay.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "bra",
            "title": "Brampton-Caledon",
            "url": "https://toronto.craigslist.org/bra/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "drh",
            "title": "Durham Region",
            "url": "https://toronto.craigslist.org/drh/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "mss",
            "title": "Mississauga",
            "url": "https://toronto.craigslist.org/mss/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "oak",
            "title": "Oakville-Milton",
            "url": "https://toronto.craigslist.org/oak/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "tor",
            "title": "City of Toronto",
            "url": "https://toronto.craigslist.org/tor/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {"key": "toronto", "title": "Toronto", "url": "https://toronto.craigslist.org/",},
        "area": {
            "key": "yrk",
            "title": "York Region",
            "url": "https://toronto.craigslist.org/yrk/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "troisrivieres",
            "title": "Trois-Rivieres, QC",
            "url": "https://troisrivieres.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "bnc",
            "title": "Burnaby/Newwest",
            "url": "https://vancouver.craigslist.org/bnc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "nvn",
            "title": "North Shore",
            "url": "https://vancouver.craigslist.org/nvn/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "pml",
            "title": "Tricities/Pitt/Maple",
            "url": "https://vancouver.craigslist.org/pml/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "rch",
            "title": "Richmond",
            "url": "https://vancouver.craigslist.org/rch/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "rds",
            "title": "Delta/Surrey/Langley",
            "url": "https://vancouver.craigslist.org/rds/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "vancouver",
            "title": "Vancouver, BC",
            "url": "https://vancouver.craigslist.org/",
        },
        "area": {
            "key": "van",
            "title": "City of Vancouver",
            "url": "https://vancouver.craigslist.org/van/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "whistler",
            "title": "Whistler / Squamish",
            "url": "https://whistler.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "whitehorse",
            "title": "Whitehorse, YT",
            "url": "https://whitehorse.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "winnipeg",
            "title": "Winnipeg, MB",
            "url": "https://winnipeg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "canada", "title": "Canada"},
        "site": {
            "key": "yellowknife",
            "title": "Yellowknife, NT",
            "url": "https://yellowknife.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "chile", "title": "Chile"},
        "site": {"key": "santiago", "title": "Chile", "url": "https://santiago.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "colombia", "title": "Colombia"},
        "site": {
            "key": "colombia",
            "title": "Colombia",
            "url": "https://colombia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "costa_rica", "title": "Costa Rica"},
        "site": {
            "key": "costarica",
            "title": "Costa Rica",
            "url": "https://costarica.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "dominican_republic", "title": "Dominican Republic"},
        "site": {
            "key": "santodomingo",
            "title": "Rep\u00fablica Dominicana",
            "url": "https://santodomingo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "ecuador", "title": "Ecuador"},
        "site": {"key": "quito", "title": "Ecuador", "url": "https://quito.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "el_salvador", "title": "El Salvador"},
        "site": {
            "key": "elsalvador",
            "title": "El Salvador",
            "url": "https://elsalvador.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "guatemala", "title": "Guatemala"},
        "site": {
            "key": "guatemala",
            "title": "Guatemala",
            "url": "https://guatemala.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "acapulco",
            "title": "Acapulco",
            "url": "https://acapulco.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "bajasur",
            "title": "Baja California Sur",
            "url": "https://bajasur.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "chihuahua",
            "title": "Chihuahua",
            "url": "https://chihuahua.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "guadalajara",
            "title": "Guadalajara, MX",
            "url": "https://guadalajara.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "guanajuato",
            "title": "Guanajuato",
            "url": "https://guanajuato.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "hermosillo",
            "title": "Hermosillo",
            "url": "https://hermosillo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "juarez",
            "title": "Ciudad Ju\u00e1rez",
            "url": "https://juarez.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "mazatlan",
            "title": "Mazatl\u00e1n",
            "url": "https://mazatlan.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "mexicocity",
            "title": "Ciudad De M\u00e9xico",
            "url": "https://mexicocity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "monterrey",
            "title": "Monterrey",
            "url": "https://monterrey.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {"key": "oaxaca", "title": "Oaxaca", "url": "https://oaxaca.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {"key": "puebla", "title": "Puebla, MX", "url": "https://puebla.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {"key": "pv", "title": "Puerto Vallarta", "url": "https://pv.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "tijuana",
            "title": "Tijuana, MX",
            "url": "https://tijuana.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "veracruz",
            "title": "Veracruz",
            "url": "https://veracruz.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "mexico", "title": "Mexico"},
        "site": {
            "key": "yucatan",
            "title": "Yucat\u00e1n",
            "url": "https://yucatan.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "nicaragua", "title": "Nicaragua"},
        "site": {"key": "managua", "title": "Nicaragua", "url": "https://managua.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "panama", "title": "Panama"},
        "site": {"key": "panama", "title": "Panama", "url": "https://panama.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "peru", "title": "Peru"},
        "site": {"key": "lima", "title": "Peru", "url": "https://lima.craigslist.org/"},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "puerto_rico", "title": "Puerto Rico"},
        "site": {
            "key": "puertorico",
            "title": "Puerto Rico",
            "url": "https://puertorico.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "abilene",
            "title": "Abilene, TX",
            "url": "https://abilene.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "akroncanton",
            "title": "Akron / Canton",
            "url": "https://akroncanton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "albany", "title": "Albany, NY", "url": "https://albany.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "albanyga",
            "title": "Albany, GA",
            "url": "https://albanyga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "albuquerque",
            "title": "Albuquerque",
            "url": "https://albuquerque.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "allentown",
            "title": "Lehigh Valley",
            "url": "https://allentown.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "altoona",
            "title": "Altoona-Johnstown",
            "url": "https://altoona.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "amarillo",
            "title": "Amarillo, TX",
            "url": "https://amarillo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "ames", "title": "Ames, IA", "url": "https://ames.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "anchorage",
            "title": "Anchorage / Mat-Su",
            "url": "https://anchorage.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "annapolis",
            "title": "Annapolis, MD",
            "url": "https://annapolis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "annarbor",
            "title": "Ann Arbor, MI",
            "url": "https://annarbor.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "appleton",
            "title": "Appleton-Oshkosh-Fdl",
            "url": "https://appleton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "asheville",
            "title": "Asheville, NC",
            "url": "https://asheville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "ashtabula",
            "title": "Ashtabula, OH",
            "url": "https://ashtabula.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "athensga",
            "title": "Athens, GA",
            "url": "https://athensga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "athensohio",
            "title": "Athens, OH",
            "url": "https://athensohio.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "atlanta",
            "title": "Atlanta, GA",
            "url": "https://atlanta.craigslist.org/",
        },
        "area": {
            "key": "atl",
            "title": "City of Atlanta",
            "url": "https://atlanta.craigslist.org/atl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "atlanta",
            "title": "Atlanta, GA",
            "url": "https://atlanta.craigslist.org/",
        },
        "area": {"key": "eat", "title": "Otp East", "url": "https://atlanta.craigslist.org/eat/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "atlanta",
            "title": "Atlanta, GA",
            "url": "https://atlanta.craigslist.org/",
        },
        "area": {"key": "nat", "title": "Otp North", "url": "https://atlanta.craigslist.org/nat/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "atlanta",
            "title": "Atlanta, GA",
            "url": "https://atlanta.craigslist.org/",
        },
        "area": {"key": "sat", "title": "Otp South", "url": "https://atlanta.craigslist.org/sat/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "atlanta",
            "title": "Atlanta, GA",
            "url": "https://atlanta.craigslist.org/",
        },
        "area": {"key": "wat", "title": "Otp West", "url": "https://atlanta.craigslist.org/wat/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "auburn", "title": "Auburn, AL", "url": "https://auburn.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "austin", "title": "Austin, TX", "url": "https://austin.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bakersfield",
            "title": "Bakersfield, CA",
            "url": "https://bakersfield.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "baltimore",
            "title": "Baltimore, MD",
            "url": "https://baltimore.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "batonrouge",
            "title": "Baton Rouge",
            "url": "https://batonrouge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "battlecreek",
            "title": "Battle Creek, MI",
            "url": "https://battlecreek.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "beaumont",
            "title": "Beaumont / Port Arthur",
            "url": "https://beaumont.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bellingham",
            "title": "Bellingham, WA",
            "url": "https://bellingham.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bemidji",
            "title": "Bemidji, MN",
            "url": "https://bemidji.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "bend", "title": "Bend, OR", "url": "https://bend.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bgky",
            "title": "Bowling Green, KY",
            "url": "https://bgky.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "bham", "title": "Birmingham, AL", "url": "https://bham.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bigbend",
            "title": "Southwest Tx",
            "url": "https://bigbend.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "billings",
            "title": "Billings, MT",
            "url": "https://billings.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "binghamton",
            "title": "Binghamton, NY",
            "url": "https://binghamton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bismarck",
            "title": "Bismarck, ND",
            "url": "https://bismarck.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "blacksburg",
            "title": "New River Valley",
            "url": "https://blacksburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bloomington",
            "title": "Bloomington, IN",
            "url": "https://bloomington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "bn", "title": "Bloomington-Normal", "url": "https://bn.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boise", "title": "Boise, ID", "url": "https://boise.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boone", "title": "Boone, NC", "url": "https://boone.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boston", "title": "Boston", "url": "https://boston.craigslist.org/",},
        "area": {"key": "bmw", "title": "Metro West", "url": "https://boston.craigslist.org/bmw/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boston", "title": "Boston", "url": "https://boston.craigslist.org/",},
        "area": {
            "key": "gbs",
            "title": "Boston/Cambridge/Brookline",
            "url": "https://boston.craigslist.org/gbs/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boston", "title": "Boston", "url": "https://boston.craigslist.org/",},
        "area": {
            "key": "nos",
            "title": "North Shore",
            "url": "https://boston.craigslist.org/nos/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boston", "title": "Boston", "url": "https://boston.craigslist.org/",},
        "area": {
            "key": "nwb",
            "title": "Northwest/Merrimack",
            "url": "https://boston.craigslist.org/nwb/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "boston", "title": "Boston", "url": "https://boston.craigslist.org/",},
        "area": {
            "key": "sob",
            "title": "South Shore",
            "url": "https://boston.craigslist.org/sob/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "boulder",
            "title": "Boulder, CO",
            "url": "https://boulder.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "bozeman",
            "title": "Bozeman, MT",
            "url": "https://bozeman.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "brainerd",
            "title": "Brainerd, MN",
            "url": "https://brainerd.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "brownsville",
            "title": "Brownsville, TX",
            "url": "https://brownsville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "brunswick",
            "title": "Brunswick, GA",
            "url": "https://brunswick.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "buffalo",
            "title": "Buffalo, NY",
            "url": "https://buffalo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "butte", "title": "Butte, MT", "url": "https://butte.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "carbondale",
            "title": "Southern Illinois",
            "url": "https://carbondale.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "catskills",
            "title": "Catskills",
            "url": "https://catskills.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cedarrapids",
            "title": "Cedar Rapids, IA",
            "url": "https://cedarrapids.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cenla",
            "title": "Central Louisiana",
            "url": "https://cenla.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "centralmich",
            "title": "Central Michigan",
            "url": "https://centralmich.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "cfl", "title": "Heartland Florida", "url": "https://cfl.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "chambana",
            "title": "Champaign Urbana",
            "url": "https://chambana.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "chambersburg",
            "title": "Cumberland Valley",
            "url": "https://chambersburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "charleston",
            "title": "Charleston, SC",
            "url": "https://charleston.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "charlestonwv",
            "title": "Charleston, WV",
            "url": "https://charlestonwv.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "charlotte",
            "title": "Charlotte, NC",
            "url": "https://charlotte.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "charlottesville",
            "title": "Charlottesville, VA",
            "url": "https://charlottesville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "chattanooga",
            "title": "Chattanooga, TN",
            "url": "https://chattanooga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "chautauqua",
            "title": "Chautauqua, NY",
            "url": "https://chautauqua.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "chc",
            "title": "City of Chicago",
            "url": "https://chicago.craigslist.org/chc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "nch",
            "title": "North Chicagoland",
            "url": "https://chicago.craigslist.org/nch/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "nwc",
            "title": "Northwest Suburbs",
            "url": "https://chicago.craigslist.org/nwc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "nwi",
            "title": "Northwest Indiana",
            "url": "https://chicago.craigslist.org/nwi/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "sox",
            "title": "South Chicagoland",
            "url": "https://chicago.craigslist.org/sox/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chicago", "title": "Chicago", "url": "https://chicago.craigslist.org/",},
        "area": {
            "key": "wcl",
            "title": "West Chicagoland",
            "url": "https://chicago.craigslist.org/wcl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "chico", "title": "Chico, CA", "url": "https://chico.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "chillicothe",
            "title": "Chillicothe, OH",
            "url": "https://chillicothe.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cincinnati",
            "title": "Cincinnati, OH",
            "url": "https://cincinnati.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "clarksville",
            "title": "Clarksville, TN",
            "url": "https://clarksville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cleveland",
            "title": "Cleveland, OH",
            "url": "https://cleveland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "clovis",
            "title": "Clovis / Portales",
            "url": "https://clovis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "cnj", "title": "Central Nj", "url": "https://cnj.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "collegestation",
            "title": "College Station, TX",
            "url": "https://collegestation.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "columbia",
            "title": "Columbia, SC",
            "url": "https://columbia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "columbiamo",
            "title": "Columbia / Jeff City",
            "url": "https://columbiamo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "columbus",
            "title": "Columbus, OH",
            "url": "https://columbus.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "columbusga",
            "title": "Columbus, GA",
            "url": "https://columbusga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cookeville",
            "title": "Cookeville, TN",
            "url": "https://cookeville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "corpuschristi",
            "title": "Corpus Christi, TX",
            "url": "https://corpuschristi.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "corvallis",
            "title": "Corvallis/Albany",
            "url": "https://corvallis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "cosprings",
            "title": "Colorado Springs",
            "url": "https://cosprings.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "csd",
            "title": "Pierre / Central Sd",
            "url": "https://csd.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dallas",
            "title": "Dallas / Fort Worth",
            "url": "https://dallas.craigslist.org/",
        },
        "area": {"key": "dal", "title": "Dallas", "url": "https://dallas.craigslist.org/dal/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dallas",
            "title": "Dallas / Fort Worth",
            "url": "https://dallas.craigslist.org/",
        },
        "area": {"key": "ftw", "title": "Fort Worth", "url": "https://dallas.craigslist.org/ftw/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dallas",
            "title": "Dallas / Fort Worth",
            "url": "https://dallas.craigslist.org/",
        },
        "area": {"key": "mdf", "title": "Mid Cities", "url": "https://dallas.craigslist.org/mdf/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dallas",
            "title": "Dallas / Fort Worth",
            "url": "https://dallas.craigslist.org/",
        },
        "area": {"key": "ndf", "title": "North Dfw", "url": "https://dallas.craigslist.org/ndf/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dallas",
            "title": "Dallas / Fort Worth",
            "url": "https://dallas.craigslist.org/",
        },
        "area": {"key": "sdf", "title": "South Dfw", "url": "https://dallas.craigslist.org/sdf/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "danville",
            "title": "Danville",
            "url": "https://danville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "dayton",
            "title": "Dayton / Springfield",
            "url": "https://dayton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "daytona",
            "title": "Daytona Beach",
            "url": "https://daytona.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "delaware",
            "title": "Delaware",
            "url": "https://delaware.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "denver", "title": "Denver, CO", "url": "https://denver.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "desmoines",
            "title": "Des Moines, IA",
            "url": "https://desmoines.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "detroit",
            "title": "Detroit Metro",
            "url": "https://detroit.craigslist.org/",
        },
        "area": {
            "key": "mcb",
            "title": "Macomb County",
            "url": "https://detroit.craigslist.org/mcb/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "detroit",
            "title": "Detroit Metro",
            "url": "https://detroit.craigslist.org/",
        },
        "area": {
            "key": "okl",
            "title": "Oakland County",
            "url": "https://detroit.craigslist.org/okl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "detroit",
            "title": "Detroit Metro",
            "url": "https://detroit.craigslist.org/",
        },
        "area": {
            "key": "wyn",
            "title": "Wayne County",
            "url": "https://detroit.craigslist.org/wyn/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "dothan", "title": "Dothan, AL", "url": "https://dothan.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "dubuque", "title": "Dubuque", "url": "https://dubuque.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "duluth",
            "title": "Duluth / Superior",
            "url": "https://duluth.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "eastco", "title": "Eastern Co", "url": "https://eastco.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "easternshore",
            "title": "Eastern Shore",
            "url": "https://easternshore.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "eastidaho",
            "title": "East Idaho",
            "url": "https://eastidaho.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "eastky",
            "title": "Eastern Kentucky",
            "url": "https://eastky.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "eastnc", "title": "Eastern Nc", "url": "https://eastnc.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "eastoregon",
            "title": "East Oregon",
            "url": "https://eastoregon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "easttexas",
            "title": "Tyler / East Tx",
            "url": "https://easttexas.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "eauclaire",
            "title": "Eau Claire, WI",
            "url": "https://eauclaire.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "elko", "title": "Elko, NV", "url": "https://elko.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "elmira",
            "title": "Elmira-Corning",
            "url": "https://elmira.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "elpaso", "title": "El Paso, TX", "url": "https://elpaso.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "enid", "title": "Northwest Ok", "url": "https://enid.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "erie", "title": "Erie, PA", "url": "https://erie.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "eugene", "title": "Eugene, OR", "url": "https://eugene.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "evansville",
            "title": "Evansville, IN",
            "url": "https://evansville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fairbanks",
            "title": "Fairbanks, AK",
            "url": "https://fairbanks.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fargo",
            "title": "Fargo / Moorhead",
            "url": "https://fargo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "farmington",
            "title": "Farmington, NM",
            "url": "https://farmington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fayar",
            "title": "Fayetteville, AR",
            "url": "https://fayar.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fayetteville",
            "title": "Fayetteville, NC",
            "url": "https://fayetteville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fingerlakes",
            "title": "Finger Lakes, NY",
            "url": "https://fingerlakes.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "flagstaff",
            "title": "Flagstaff / Sedona",
            "url": "https://flagstaff.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "florencesc",
            "title": "Florence, SC",
            "url": "https://florencesc.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortcollins",
            "title": "Fort Collins / North Co",
            "url": "https://fortcollins.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortdodge",
            "title": "Fort Dodge, IA",
            "url": "https://fortdodge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortlauderdale",
            "title": "South Florida",
            "url": "https://fortlauderdale.craigslist.org/",
        },
        "area": {
            "key": "brw",
            "title": "Broward County",
            "url": "https://fortlauderdale.craigslist.org/brw/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortlauderdale",
            "title": "South Florida",
            "url": "https://fortlauderdale.craigslist.org/",
        },
        "area": {
            "key": "mdc",
            "title": "Miami / Dade County",
            "url": "https://fortlauderdale.craigslist.org/mdc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortlauderdale",
            "title": "South Florida",
            "url": "https://fortlauderdale.craigslist.org/",
        },
        "area": {
            "key": "pbc",
            "title": "Palm Beach County",
            "url": "https://fortlauderdale.craigslist.org/pbc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortmyers",
            "title": "Ft Myers / Sw Florida",
            "url": "https://fortmyers.craigslist.org/",
        },
        "area": {
            "key": "chl",
            "title": "Charlotte County",
            "url": "https://fortmyers.craigslist.org/chl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortmyers",
            "title": "Ft Myers / Sw Florida",
            "url": "https://fortmyers.craigslist.org/",
        },
        "area": {
            "key": "col",
            "title": "Collier County",
            "url": "https://fortmyers.craigslist.org/col/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortmyers",
            "title": "Ft Myers / Sw Florida",
            "url": "https://fortmyers.craigslist.org/",
        },
        "area": {
            "key": "lee",
            "title": "Lee County",
            "url": "https://fortmyers.craigslist.org/lee/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortsmith",
            "title": "Fort Smith, AR",
            "url": "https://fortsmith.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fortwayne",
            "title": "Fort Wayne, IN",
            "url": "https://fortwayne.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "frederick",
            "title": "Frederick, MD",
            "url": "https://frederick.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fredericksburg",
            "title": "Fredericksburg, VA",
            "url": "https://fredericksburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "fresno",
            "title": "Fresno / Madera",
            "url": "https://fresno.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "gadsden",
            "title": "Gadsden-Anniston",
            "url": "https://gadsden.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "galveston",
            "title": "Galveston, TX",
            "url": "https://galveston.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "glensfalls",
            "title": "Glens Falls, NY",
            "url": "https://glensfalls.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "goldcountry",
            "title": "Gold Country",
            "url": "https://goldcountry.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "grandforks",
            "title": "Grand Forks",
            "url": "https://grandforks.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "grandisland",
            "title": "Grand Island, NE",
            "url": "https://grandisland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "grandrapids",
            "title": "Grand Rapids, MI",
            "url": "https://grandrapids.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "greatfalls",
            "title": "Great Falls, MT",
            "url": "https://greatfalls.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "greenbay",
            "title": "Green Bay, WI",
            "url": "https://greenbay.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "greensboro",
            "title": "Greensboro, NC",
            "url": "https://greensboro.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "greenville",
            "title": "Greenville / Upstate",
            "url": "https://greenville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "gulfport",
            "title": "Gulfport / Biloxi",
            "url": "https://gulfport.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hanford",
            "title": "Hanford-Corcoran",
            "url": "https://hanford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "harrisburg",
            "title": "Harrisburg, PA",
            "url": "https://harrisburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "harrisonburg",
            "title": "Harrisonburg, VA",
            "url": "https://harrisonburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hartford",
            "title": "Hartford, CT",
            "url": "https://hartford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hattiesburg",
            "title": "Hattiesburg, MS",
            "url": "https://hattiesburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "helena", "title": "Helena, MT", "url": "https://helena.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hickory",
            "title": "Hickory / Lenoir",
            "url": "https://hickory.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hiltonhead",
            "title": "Hilton Head",
            "url": "https://hiltonhead.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "holland",
            "title": "Holland, MI",
            "url": "https://holland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "honolulu", "title": "Hawaii", "url": "https://honolulu.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "houma", "title": "Houma, LA", "url": "https://houma.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "houston",
            "title": "Houston, TX",
            "url": "https://houston.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "hudsonvalley",
            "title": "Hudson Valley, NY",
            "url": "https://hudsonvalley.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "humboldt",
            "title": "Humboldt County",
            "url": "https://humboldt.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "huntington",
            "title": "Huntington-Ashland",
            "url": "https://huntington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "huntsville",
            "title": "Huntsville / Decatur",
            "url": "https://huntsville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "imperial",
            "title": "Imperial County",
            "url": "https://imperial.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "indianapolis",
            "title": "Indianapolis",
            "url": "https://indianapolis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "inlandempire",
            "title": "Inland Empire, CA",
            "url": "https://inlandempire.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "iowacity",
            "title": "Iowa City, IA",
            "url": "https://iowacity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "ithaca", "title": "Ithaca, NY", "url": "https://ithaca.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "jackson",
            "title": "Jackson, MS",
            "url": "https://jackson.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "jacksontn",
            "title": "Jackson, TN",
            "url": "https://jacksontn.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "jacksonville",
            "title": "Jacksonville, FL",
            "url": "https://jacksonville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "janesville",
            "title": "Janesville, WI",
            "url": "https://janesville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "jerseyshore",
            "title": "Jersey Shore",
            "url": "https://jerseyshore.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "jonesboro",
            "title": "Jonesboro, AR",
            "url": "https://jonesboro.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "joplin", "title": "Joplin, MO", "url": "https://joplin.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "juneau",
            "title": "Southeast Alaska",
            "url": "https://juneau.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "jxn", "title": "Jackson, MI", "url": "https://jxn.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kalamazoo",
            "title": "Kalamazoo, MI",
            "url": "https://kalamazoo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kalispell",
            "title": "Kalispell, MT",
            "url": "https://kalispell.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kansascity",
            "title": "Kansas City, MO",
            "url": "https://kansascity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kenai",
            "title": "Kenai Peninsula",
            "url": "https://kenai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "keys", "title": "Florida Keys", "url": "https://keys.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "killeen",
            "title": "Killeen / Temple / Ft Hood",
            "url": "https://killeen.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kirksville",
            "title": "Kirksville, MO",
            "url": "https://kirksville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "klamath",
            "title": "Klamath Falls, OR",
            "url": "https://klamath.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "knoxville",
            "title": "Knoxville, TN",
            "url": "https://knoxville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "kokomo", "title": "Kokomo, IN", "url": "https://kokomo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "kpr",
            "title": "Kennewick-Pasco-Richland",
            "url": "https://kpr.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "ksu", "title": "Manhattan, KS", "url": "https://ksu.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lacrosse",
            "title": "La Crosse, WI",
            "url": "https://lacrosse.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lafayette",
            "title": "Lafayette, LA",
            "url": "https://lafayette.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lakecharles",
            "title": "Lake Charles, LA",
            "url": "https://lakecharles.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lakecity",
            "title": "North Central Fl",
            "url": "https://lakecity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lakeland",
            "title": "Lakeland, FL",
            "url": "https://lakeland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lancaster",
            "title": "Lancaster, PA",
            "url": "https://lancaster.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lansing",
            "title": "Lansing, MI",
            "url": "https://lansing.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "laredo", "title": "Laredo, TX", "url": "https://laredo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lasalle",
            "title": "La Salle Co",
            "url": "https://lasalle.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lascruces",
            "title": "Las Cruces, NM",
            "url": "https://lascruces.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lasvegas",
            "title": "Las Vegas",
            "url": "https://lasvegas.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lawrence",
            "title": "Lawrence, KS",
            "url": "https://lawrence.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "lawton", "title": "Lawton, OK", "url": "https://lawton.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lewiston",
            "title": "Lewiston / Clarkston",
            "url": "https://lewiston.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lexington",
            "title": "Lexington, KY",
            "url": "https://lexington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "limaohio",
            "title": "Lima / Findlay",
            "url": "https://limaohio.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lincoln",
            "title": "Lincoln, NE",
            "url": "https://lincoln.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "littlerock",
            "title": "Little Rock",
            "url": "https://littlerock.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "logan", "title": "Logan, UT", "url": "https://logan.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "longisland",
            "title": "Long Island, NY",
            "url": "https://longisland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "ant",
            "title": "Antelope Valley",
            "url": "https://losangeles.craigslist.org/ant/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "lac",
            "title": "Central La 213/323",
            "url": "https://losangeles.craigslist.org/lac/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "lgb",
            "title": "Long Beach / 562",
            "url": "https://losangeles.craigslist.org/lgb/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "sfv",
            "title": "San Fernando Valley",
            "url": "https://losangeles.craigslist.org/sfv/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "sgv",
            "title": "San Gabriel Valley",
            "url": "https://losangeles.craigslist.org/sgv/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "losangeles",
            "title": "Los Angeles",
            "url": "https://losangeles.craigslist.org/",
        },
        "area": {
            "key": "wst",
            "title": "Westside-Southbay-310",
            "url": "https://losangeles.craigslist.org/wst/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "louisville",
            "title": "Louisville, KY",
            "url": "https://louisville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "loz",
            "title": "Lake of The Ozarks",
            "url": "https://loz.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lubbock",
            "title": "Lubbock, TX",
            "url": "https://lubbock.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "lynchburg",
            "title": "Lynchburg, VA",
            "url": "https://lynchburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "macon",
            "title": "Macon / Warner Robins",
            "url": "https://macon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "madison",
            "title": "Madison, WI",
            "url": "https://madison.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "maine", "title": "Maine", "url": "https://maine.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "mankato",
            "title": "Mankato, MN",
            "url": "https://mankato.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "mansfield",
            "title": "Mansfield, OH",
            "url": "https://mansfield.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "marshall",
            "title": "Southwest Mn",
            "url": "https://marshall.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "martinsburg",
            "title": "Eastern Panhandle",
            "url": "https://martinsburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "masoncity",
            "title": "Mason City, IA",
            "url": "https://masoncity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "mattoon",
            "title": "Mattoon-Charleston",
            "url": "https://mattoon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "mcallen",
            "title": "Mcallen / Edinburg",
            "url": "https://mcallen.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "meadville",
            "title": "Meadville, PA",
            "url": "https://meadville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "medford",
            "title": "Medford-Ashland",
            "url": "https://medford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "memphis",
            "title": "Memphis, TN",
            "url": "https://memphis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "merced", "title": "Merced, CA", "url": "https://merced.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "meridian",
            "title": "Meridian, MS",
            "url": "https://meridian.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "miami", "title": "South Florida", "url": "https://miami.craigslist.org/",},
        "area": {
            "key": "brw",
            "title": "Broward County",
            "url": "https://miami.craigslist.org/brw/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "miami", "title": "South Florida", "url": "https://miami.craigslist.org/",},
        "area": {
            "key": "mdc",
            "title": "Miami / Dade County",
            "url": "https://miami.craigslist.org/mdc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "milwaukee",
            "title": "Milwaukee, WI",
            "url": "https://milwaukee.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "ank",
            "title": "Anoka/Chisago/Isanti",
            "url": "https://minneapolis.craigslist.org/ank/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "csw",
            "title": "Carver/Sherburne/Wright",
            "url": "https://minneapolis.craigslist.org/csw/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "dak",
            "title": "Dakota / Scott",
            "url": "https://minneapolis.craigslist.org/dak/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "hnp",
            "title": "Hennepin County",
            "url": "https://minneapolis.craigslist.org/hnp/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "ram",
            "title": "Ramsey County",
            "url": "https://minneapolis.craigslist.org/ram/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "minneapolis",
            "title": "Minneapolis / St Paul",
            "url": "https://minneapolis.craigslist.org/",
        },
        "area": {
            "key": "wsh",
            "title": "Washington Co / Wi",
            "url": "https://minneapolis.craigslist.org/wsh/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "missoula",
            "title": "Missoula, MT",
            "url": "https://missoula.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "mobile", "title": "Mobile, AL", "url": "https://mobile.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "modesto",
            "title": "Modesto, CA",
            "url": "https://modesto.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "mohave",
            "title": "Mohave County",
            "url": "https://mohave.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "monroe", "title": "Monroe, LA", "url": "https://monroe.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "monroemi",
            "title": "Monroe, MI",
            "url": "https://monroemi.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "montana",
            "title": "Eastern Montana",
            "url": "https://montana.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "monterey",
            "title": "Monterey Bay",
            "url": "https://monterey.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "montgomery",
            "title": "Montgomery, AL",
            "url": "https://montgomery.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "morgantown",
            "title": "Morgantown, WV",
            "url": "https://morgantown.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "moseslake",
            "title": "Moses Lake, WA",
            "url": "https://moseslake.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "muncie",
            "title": "Muncie / Anderson",
            "url": "https://muncie.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "muskegon",
            "title": "Muskegon, MI",
            "url": "https://muskegon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "myrtlebeach",
            "title": "Myrtle Beach, SC",
            "url": "https://myrtlebeach.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "nacogdoches",
            "title": "Deep East Texas",
            "url": "https://nacogdoches.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "nashville",
            "title": "Nashville, TN",
            "url": "https://nashville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "natchez",
            "title": "Southwest Ms",
            "url": "https://natchez.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nd", "title": "North Dakota", "url": "https://nd.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nesd", "title": "Northeast Sd", "url": "https://nesd.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newhaven",
            "title": "New Haven, CT",
            "url": "https://newhaven.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newjersey",
            "title": "North Jersey",
            "url": "https://newjersey.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newlondon",
            "title": "Eastern Ct",
            "url": "https://newlondon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "neworleans",
            "title": "New Orleans",
            "url": "https://neworleans.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {"key": "brk", "title": "Brooklyn", "url": "https://newyork.craigslist.org/brk/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {"key": "brx", "title": "Bronx", "url": "https://newyork.craigslist.org/brx/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {
            "key": "fct",
            "title": "Fairfield Co, CT",
            "url": "https://newyork.craigslist.org/fct/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {
            "key": "jsy",
            "title": "New Jersey",
            "url": "https://newyork.craigslist.org/jsy/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {
            "key": "lgi",
            "title": "Long Island",
            "url": "https://newyork.craigslist.org/lgi/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {"key": "mnh", "title": "Manhattan", "url": "https://newyork.craigslist.org/mnh/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {"key": "que", "title": "Queens", "url": "https://newyork.craigslist.org/que/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {
            "key": "stn",
            "title": "Staten Island",
            "url": "https://newyork.craigslist.org/stn/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "newyork",
            "title": "New York City",
            "url": "https://newyork.craigslist.org/",
        },
        "area": {
            "key": "wch",
            "title": "Westchester",
            "url": "https://newyork.craigslist.org/wch/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nh", "title": "New Hampshire", "url": "https://nh.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nmi", "title": "Northern Michigan", "url": "https://nmi.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "norfolk",
            "title": "Norfolk / Hampton Roads",
            "url": "https://norfolk.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "northernwi",
            "title": "Northern Wi",
            "url": "https://northernwi.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "northmiss",
            "title": "North Mississippi",
            "url": "https://northmiss.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "northplatte",
            "title": "North Platte, NE",
            "url": "https://northplatte.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nwct", "title": "Northwest Ct", "url": "https://nwct.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nwga", "title": "Northwest Ga", "url": "https://nwga.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "nwks", "title": "Northwest Ks", "url": "https://nwks.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "odessa",
            "title": "Odessa / Midland",
            "url": "https://odessa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "ogden",
            "title": "Ogden-Clearfield",
            "url": "https://ogden.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "okaloosa",
            "title": "Okaloosa / Walton",
            "url": "https://okaloosa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "oklahomacity",
            "title": "Oklahoma City",
            "url": "https://oklahomacity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "olympic",
            "title": "Olympic Peninsula",
            "url": "https://olympic.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "omaha",
            "title": "Omaha / Council Bluffs",
            "url": "https://omaha.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "onslow",
            "title": "Jacksonville, NC",
            "url": "https://onslow.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "orangecounty",
            "title": "Orange County, CA",
            "url": "https://orangecounty.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "oregoncoast",
            "title": "Oregon Coast",
            "url": "https://oregoncoast.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "orlando",
            "title": "Orlando, FL",
            "url": "https://orlando.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "ottumwa",
            "title": "Southeast Ia",
            "url": "https://ottumwa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "outerbanks",
            "title": "Outer Banks",
            "url": "https://outerbanks.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "owensboro",
            "title": "Owensboro, KY",
            "url": "https://owensboro.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "palmsprings",
            "title": "Palm Springs, CA",
            "url": "https://palmsprings.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "panamacity",
            "title": "Panama City, FL",
            "url": "https://panamacity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "parkersburg",
            "title": "Parkersburg-Marietta",
            "url": "https://parkersburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "pennstate",
            "title": "State College, PA",
            "url": "https://pennstate.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "pensacola",
            "title": "Pensacola, FL",
            "url": "https://pensacola.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "peoria", "title": "Peoria, IL", "url": "https://peoria.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "philadelphia",
            "title": "Philadelphia",
            "url": "https://philadelphia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "phoenix",
            "title": "Phoenix, AZ",
            "url": "https://phoenix.craigslist.org/",
        },
        "area": {
            "key": "cph",
            "title": "Central/South Phx",
            "url": "https://phoenix.craigslist.org/cph/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "phoenix",
            "title": "Phoenix, AZ",
            "url": "https://phoenix.craigslist.org/",
        },
        "area": {
            "key": "evl",
            "title": "East Valley",
            "url": "https://phoenix.craigslist.org/evl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "phoenix",
            "title": "Phoenix, AZ",
            "url": "https://phoenix.craigslist.org/",
        },
        "area": {"key": "nph", "title": "Phx North", "url": "https://phoenix.craigslist.org/nph/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "phoenix",
            "title": "Phoenix, AZ",
            "url": "https://phoenix.craigslist.org/",
        },
        "area": {
            "key": "wvl",
            "title": "West Valley",
            "url": "https://phoenix.craigslist.org/wvl/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "pittsburgh",
            "title": "Pittsburgh, PA",
            "url": "https://pittsburgh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "plattsburgh",
            "title": "Plattsburgh-Adirondacks",
            "url": "https://plattsburgh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "poconos", "title": "Poconos", "url": "https://poconos.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "porthuron",
            "title": "Port Huron, MI",
            "url": "https://porthuron.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "clc",
            "title": "Clackamas County",
            "url": "https://portland.craigslist.org/clc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "clk",
            "title": "Clark/Cowlitz, WA",
            "url": "https://portland.craigslist.org/clk/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "grg",
            "title": "Columbia Gorge",
            "url": "https://portland.craigslist.org/grg/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "mlt",
            "title": "Multnomah County",
            "url": "https://portland.craigslist.org/mlt/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "nco",
            "title": "North Coast",
            "url": "https://portland.craigslist.org/nco/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "wsc",
            "title": "Washington County",
            "url": "https://portland.craigslist.org/wsc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "portland",
            "title": "Portland, OR",
            "url": "https://portland.craigslist.org/",
        },
        "area": {
            "key": "yam",
            "title": "Yamhill Co",
            "url": "https://portland.craigslist.org/yam/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "potsdam",
            "title": "Potsdam-Canton-Massena",
            "url": "https://potsdam.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "providence",
            "title": "Rhode Island",
            "url": "https://providence.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "provo", "title": "Provo / Orem", "url": "https://provo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "pueblo", "title": "Pueblo, CO", "url": "https://pueblo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "pullman",
            "title": "Pullman / Moscow",
            "url": "https://pullman.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "quadcities",
            "title": "Quad Cities, Ia/Il",
            "url": "https://quadcities.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "quincy", "title": "Western Il", "url": "https://quincy.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "racine",
            "title": "Kenosha-Racine",
            "url": "https://racine.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "raleigh",
            "title": "Raleigh / Durham / Ch",
            "url": "https://raleigh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "rapidcity",
            "title": "Rapid City / West Sd",
            "url": "https://rapidcity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "reading",
            "title": "Reading, PA",
            "url": "https://reading.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "redding",
            "title": "Redding, CA",
            "url": "https://redding.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "reno", "title": "Reno / Tahoe", "url": "https://reno.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "richmond",
            "title": "Richmond, VA",
            "url": "https://richmond.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "richmondin",
            "title": "Richmond, IN",
            "url": "https://richmondin.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "roanoke",
            "title": "Roanoke, VA",
            "url": "https://roanoke.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "rochester",
            "title": "Rochester, NY",
            "url": "https://rochester.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "rockford",
            "title": "Rockford, IL",
            "url": "https://rockford.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "rockies",
            "title": "High Rockies",
            "url": "https://rockies.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "roswell",
            "title": "Roswell / Carlsbad",
            "url": "https://roswell.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sacramento",
            "title": "Sacramento",
            "url": "https://sacramento.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "saginaw",
            "title": "Saginaw-Midland-Baycity",
            "url": "https://saginaw.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "salem", "title": "Salem, OR", "url": "https://salem.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "salina", "title": "Salina, KS", "url": "https://salina.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "saltlakecity",
            "title": "Salt Lake City",
            "url": "https://saltlakecity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sanangelo",
            "title": "San Angelo, TX",
            "url": "https://sanangelo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sanantonio",
            "title": "San Antonio",
            "url": "https://sanantonio.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sandiego",
            "title": "San Diego",
            "url": "https://sandiego.craigslist.org/",
        },
        "area": {
            "key": "csd",
            "title": "City of San Diego",
            "url": "https://sandiego.craigslist.org/csd/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sandiego",
            "title": "San Diego",
            "url": "https://sandiego.craigslist.org/",
        },
        "area": {
            "key": "esd",
            "title": "East San Diego County",
            "url": "https://sandiego.craigslist.org/esd/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sandiego",
            "title": "San Diego",
            "url": "https://sandiego.craigslist.org/",
        },
        "area": {
            "key": "nsd",
            "title": "North San Diego County",
            "url": "https://sandiego.craigslist.org/nsd/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sandiego",
            "title": "San Diego",
            "url": "https://sandiego.craigslist.org/",
        },
        "area": {
            "key": "ssd",
            "title": "South San Diego County",
            "url": "https://sandiego.craigslist.org/ssd/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sandusky",
            "title": "Sandusky, OH",
            "url": "https://sandusky.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sanmarcos",
            "title": "San Marcos, TX",
            "url": "https://sanmarcos.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "santafe",
            "title": "Santa Fe / Taos",
            "url": "https://santafe.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "santamaria",
            "title": "Santa Maria, CA",
            "url": "https://santamaria.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sarasota",
            "title": "Sarasota-Bradenton",
            "url": "https://sarasota.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "savannah",
            "title": "Savannah / Hinesville",
            "url": "https://savannah.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "scottsbluff",
            "title": "Scottsbluff / Panhandle",
            "url": "https://scottsbluff.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "scranton",
            "title": "Scranton / Wilkes-Barre",
            "url": "https://scranton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sd", "title": "South Dakota", "url": "https://sd.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {"key": "est", "title": "Eastside", "url": "https://seattle.craigslist.org/est/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {
            "key": "kit",
            "title": "Kitsap / West Puget",
            "url": "https://seattle.craigslist.org/kit/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {
            "key": "oly",
            "title": "Olympia / Thurston",
            "url": "https://seattle.craigslist.org/oly/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {"key": "see", "title": "Seattle", "url": "https://seattle.craigslist.org/see/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {
            "key": "skc",
            "title": "South King Co",
            "url": "https://seattle.craigslist.org/skc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {
            "key": "sno",
            "title": "Snohomish County",
            "url": "https://seattle.craigslist.org/sno/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "seattle",
            "title": "Seattle-Tacoma",
            "url": "https://seattle.craigslist.org/",
        },
        "area": {
            "key": "tac",
            "title": "Tacoma / Pierce",
            "url": "https://seattle.craigslist.org/tac/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "seks", "title": "Southeast Ks", "url": "https://seks.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "semo",
            "title": "Southeast Missouri",
            "url": "https://semo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {
            "key": "eby",
            "title": "East Bay Area",
            "url": "https://sfbay.craigslist.org/eby/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {
            "key": "nby",
            "title": "North Bay / Marin",
            "url": "https://sfbay.craigslist.org/nby/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {"key": "pen", "title": "Peninsula", "url": "https://sfbay.craigslist.org/pen/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {
            "key": "sby",
            "title": "South Bay Area",
            "url": "https://sfbay.craigslist.org/sby/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {
            "key": "scz",
            "title": "Santa Cruz Co",
            "url": "https://sfbay.craigslist.org/scz/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "sfbay", "title": "Sf Bay Area", "url": "https://sfbay.craigslist.org/",},
        "area": {
            "key": "sfc",
            "title": "City of San Francisco",
            "url": "https://sfbay.craigslist.org/sfc/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sheboygan",
            "title": "Sheboygan, WI",
            "url": "https://sheboygan.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "shoals",
            "title": "Florence / Muscle Shoals",
            "url": "https://shoals.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "showlow",
            "title": "Show Low, AZ",
            "url": "https://showlow.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "shreveport",
            "title": "Shreveport, LA",
            "url": "https://shreveport.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "sierravista",
            "title": "Sierra Vista, AZ",
            "url": "https://sierravista.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "siouxcity",
            "title": "Sioux City, IA",
            "url": "https://siouxcity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "siouxfalls",
            "title": "Sioux Falls / Se Sd",
            "url": "https://siouxfalls.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "slo", "title": "San Luis Obispo", "url": "https://slo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "smd", "title": "Southern Maryland", "url": "https://smd.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "southbend",
            "title": "South Bend / Michiana",
            "url": "https://southbend.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "southcoast",
            "title": "South Coast, MA",
            "url": "https://southcoast.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "southjersey",
            "title": "South Jersey",
            "url": "https://southjersey.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "spacecoast",
            "title": "Space Coast, FL",
            "url": "https://spacecoast.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "spokane",
            "title": "Spokane / Coeur D'Alene",
            "url": "https://spokane.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "springfield",
            "title": "Springfield, MO",
            "url": "https://springfield.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "springfieldil",
            "title": "Springfield, IL",
            "url": "https://springfieldil.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "statesboro",
            "title": "Statesboro, GA",
            "url": "https://statesboro.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "staugustine",
            "title": "St Augustine, FL",
            "url": "https://staugustine.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stcloud",
            "title": "St Cloud, MN",
            "url": "https://stcloud.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stgeorge",
            "title": "St George, UT",
            "url": "https://stgeorge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stillwater",
            "title": "Stillwater, OK",
            "url": "https://stillwater.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stjoseph",
            "title": "St Joseph",
            "url": "https://stjoseph.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stlouis",
            "title": "St Louis, MO",
            "url": "https://stlouis.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "stockton",
            "title": "Stockton, CA",
            "url": "https://stockton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "susanville",
            "title": "Susanville, CA",
            "url": "https://susanville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "swks", "title": "Southwest Ks", "url": "https://swks.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "swmi",
            "title": "Southwest Michigan",
            "url": "https://swmi.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "swv", "title": "Southern Wv", "url": "https://swv.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "swva", "title": "Southwest Va", "url": "https://swva.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "syracuse",
            "title": "Syracuse, NY",
            "url": "https://syracuse.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tallahassee",
            "title": "Tallahassee",
            "url": "https://tallahassee.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tampa",
            "title": "Tampa Bay Area",
            "url": "https://tampa.craigslist.org/",
        },
        "area": {"key": "hdo", "title": "Hernando Co", "url": "https://tampa.craigslist.org/hdo/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tampa",
            "title": "Tampa Bay Area",
            "url": "https://tampa.craigslist.org/",
        },
        "area": {
            "key": "hil",
            "title": "Hillsborough Co",
            "url": "https://tampa.craigslist.org/hil/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tampa",
            "title": "Tampa Bay Area",
            "url": "https://tampa.craigslist.org/",
        },
        "area": {"key": "pnl", "title": "Pinellas Co", "url": "https://tampa.craigslist.org/pnl/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tampa",
            "title": "Tampa Bay Area",
            "url": "https://tampa.craigslist.org/",
        },
        "area": {"key": "psc", "title": "Pasco Co", "url": "https://tampa.craigslist.org/psc/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "terrehaute",
            "title": "Terre Haute, IN",
            "url": "https://terrehaute.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "texarkana",
            "title": "Texarkana",
            "url": "https://texarkana.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "texoma", "title": "Texoma", "url": "https://texoma.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "thumb", "title": "The Thumb, MI", "url": "https://thumb.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tippecanoe",
            "title": "Lafayette / West Lafayette",
            "url": "https://tippecanoe.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "toledo", "title": "Toledo, OH", "url": "https://toledo.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "topeka", "title": "Topeka, KS", "url": "https://topeka.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tricities",
            "title": "Tri-Cities, TN",
            "url": "https://tricities.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "tucson", "title": "Tucson, AZ", "url": "https://tucson.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "tulsa", "title": "Tulsa, OK", "url": "https://tulsa.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tuscaloosa",
            "title": "Tuscaloosa",
            "url": "https://tuscaloosa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "tuscarawas",
            "title": "Tuscarawas Co",
            "url": "https://tuscarawas.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "twinfalls",
            "title": "Twin Falls, ID",
            "url": "https://twinfalls.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "twintiers",
            "title": "Twin Tiers Ny/Pa",
            "url": "https://twintiers.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "up", "title": "Upper Peninsula, MI", "url": "https://up.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "utica",
            "title": "Utica-Rome-Oneida",
            "url": "https://utica.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "valdosta",
            "title": "Valdosta, GA",
            "url": "https://valdosta.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "ventura",
            "title": "Ventura County",
            "url": "https://ventura.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "vermont", "title": "Vermont", "url": "https://vermont.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "victoriatx",
            "title": "Victoria, TX",
            "url": "https://victoriatx.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "visalia",
            "title": "Visalia-Tulare",
            "url": "https://visalia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "waco", "title": "Waco, TX", "url": "https://waco.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "washingtondc",
            "title": "Washington, DC",
            "url": "https://washingtondc.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "waterloo",
            "title": "Waterloo / Cedar Falls",
            "url": "https://waterloo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "watertown",
            "title": "Watertown, NY",
            "url": "https://watertown.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "wausau", "title": "Wausau, WI", "url": "https://wausau.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "wenatchee",
            "title": "Wenatchee, WA",
            "url": "https://wenatchee.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "westernmass",
            "title": "Western Massachusetts",
            "url": "https://westernmass.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "westky", "title": "Western Ky", "url": "https://westky.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "westmd",
            "title": "Western Maryland",
            "url": "https://westmd.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "westslope",
            "title": "Western Slope",
            "url": "https://westslope.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "wheeling",
            "title": "Northern Panhandle",
            "url": "https://wheeling.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "wichita",
            "title": "Wichita, KS",
            "url": "https://wichita.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "wichitafalls",
            "title": "Wichita Falls, TX",
            "url": "https://wichitafalls.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "williamsport",
            "title": "Williamsport, PA",
            "url": "https://williamsport.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "wilmington",
            "title": "Wilmington, NC",
            "url": "https://wilmington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "winchester",
            "title": "Winchester, VA",
            "url": "https://winchester.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "winstonsalem",
            "title": "Winston-Salem, NC",
            "url": "https://winstonsalem.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "worcester",
            "title": "Worcester / Central Ma",
            "url": "https://worcester.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "wv", "title": "West Virginia (Old)", "url": "https://wv.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "wyoming", "title": "Wyoming", "url": "https://wyoming.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "yakima", "title": "Yakima, WA", "url": "https://yakima.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "york", "title": "York, PA", "url": "https://york.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "youngstown",
            "title": "Youngstown, OH",
            "url": "https://youngstown.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "yubasutter",
            "title": "Yuba-Sutter, CA",
            "url": "https://yubasutter.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {"key": "yuma", "title": "Yuma, AZ", "url": "https://yuma.craigslist.org/",},
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "united_states", "title": "United States"},
        "site": {
            "key": "zanesville",
            "title": "Zanesville / Cambridge",
            "url": "https://zanesville.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "uruguay", "title": "Uruguay"},
        "site": {
            "key": "montevideo",
            "title": "Montevideo",
            "url": "https://montevideo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "americas", "title": "Americas"},
        "country": {"key": "venezuela", "title": "Venezuela"},
        "site": {"key": "caracas", "title": "Venezuela", "url": "https://caracas.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "bangladesh", "title": "Bangladesh"},
        "site": {
            "key": "bangladesh",
            "title": "Bangladesh",
            "url": "https://bangladesh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "beijing",
            "title": "\u5317\u4eac",
            "url": "https://beijing.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "chengdu",
            "title": "\u6210\u90fd",
            "url": "https://chengdu.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "chongqing",
            "title": "\u91cd\u5e86",
            "url": "https://chongqing.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "dalian",
            "title": "\u5927\u8fde",
            "url": "https://dalian.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "guangzhou",
            "title": "\u5e7f\u5dde",
            "url": "https://guangzhou.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "hangzhou",
            "title": "\u676d\u5dde",
            "url": "https://hangzhou.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "nanjing",
            "title": "\u5357\u4eac",
            "url": "https://nanjing.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "shanghai",
            "title": "\u4e0a\u6d77",
            "url": "https://shanghai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "shenyang",
            "title": "\u6c88\u9633",
            "url": "https://shenyang.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {
            "key": "shenzhen",
            "title": "\u6df1\u5733",
            "url": "https://shenzhen.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {"key": "wuhan", "title": "\u6b66\u6c49", "url": "https://wuhan.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "china", "title": "China"},
        "site": {"key": "xian", "title": "\u897f\u5b89", "url": "https://xian.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "hong_kong", "title": "Hong Kong"},
        "site": {
            "key": "hongkong",
            "title": "Hong Kong",
            "url": "https://hongkong.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "ahmedabad",
            "title": "Ahmedabad",
            "url": "https://ahmedabad.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "bangalore",
            "title": "Bangalore",
            "url": "https://bangalore.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "bhubaneswar",
            "title": "Bhubaneswar",
            "url": "https://bhubaneswar.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "chandigarh",
            "title": "Chandigarh",
            "url": "https://chandigarh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "chennai",
            "title": "Chennai (Madras)",
            "url": "https://chennai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "delhi", "title": "Delhi", "url": "https://delhi.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "goa", "title": "Goa", "url": "https://goa.craigslist.org/"},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "hyderabad",
            "title": "Hyderabad",
            "url": "https://hyderabad.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "indore", "title": "Indore", "url": "https://indore.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "jaipur", "title": "Jaipur", "url": "https://jaipur.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "kerala", "title": "Kerala", "url": "https://kerala.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {
            "key": "kolkata",
            "title": "Kolkata (Calcutta)",
            "url": "https://kolkata.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "lucknow", "title": "Lucknow", "url": "https://lucknow.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "mumbai", "title": "Mumbai", "url": "https://mumbai.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "pune", "title": "Pune", "url": "https://pune.craigslist.org/"},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "india", "title": "India"},
        "site": {"key": "surat", "title": "Surat Surat", "url": "https://surat.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "indonesia", "title": "Indonesia"},
        "site": {"key": "jakarta", "title": "Indonesia", "url": "https://jakarta.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "iran", "title": "Iran"},
        "site": {"key": "tehran", "title": "Iran", "url": "https://tehran.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "iraq", "title": "Iraq"},
        "site": {"key": "baghdad", "title": "Iraq", "url": "https://baghdad.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {"key": "haifa", "title": "Haifa", "url": "https://haifa.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {
            "key": "jerusalem",
            "title": "Jerusalem",
            "url": "https://jerusalem.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {
            "key": "ramallah",
            "title": "West Bank",
            "url": "https://ramallah.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {"key": "telaviv", "title": "Tel Aviv", "url": "https://telaviv.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "fukuoka",
            "title": "\u798f\u5ca1",
            "url": "https://fukuoka.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "hiroshima",
            "title": "\u5e83\u5cf6",
            "url": "https://hiroshima.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "nagoya",
            "title": "\u540d\u53e4\u5c4b",
            "url": "https://nagoya.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "okinawa",
            "title": "\u6c96\u7e04",
            "url": "https://okinawa.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "osaka",
            "title": "\u5927\u962a\u30fb\u795e\u6238\u30fb\u4eac\u90fd",
            "url": "https://osaka.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "sapporo",
            "title": "\u672d\u5e4c",
            "url": "https://sapporo.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {
            "key": "sendai",
            "title": "\u4ed9\u53f0",
            "url": "https://sendai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "japan", "title": "Japan"},
        "site": {"key": "tokyo", "title": "\u6771\u4eac", "url": "https://tokyo.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "kuwait", "title": "Kuwait"},
        "site": {"key": "kuwait", "title": "Kuwait", "url": "https://kuwait.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "lebanon", "title": "Lebanon"},
        "site": {
            "key": "beirut",
            "title": "Beirut, Lebanon",
            "url": "https://beirut.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "malaysia", "title": "Malaysia"},
        "site": {
            "key": "malaysia",
            "title": "Malaysia",
            "url": "https://malaysia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "pakistan", "title": "Pakistan"},
        "site": {
            "key": "pakistan",
            "title": "Pakistan",
            "url": "https://pakistan.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "bacolod", "title": "Bacolod", "url": "https://bacolod.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "cdo", "title": "Cagayan De Oro", "url": "https://cdo.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "cebu", "title": "Cebu", "url": "https://cebu.craigslist.org/"},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "davaocity",
            "title": "Davao City",
            "url": "https://davaocity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "iloilo", "title": "Iloilo", "url": "https://iloilo.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "manila", "title": "Manila", "url": "https://manila.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "naga", "title": "Bicol Region", "url": "https://naga.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "pampanga",
            "title": "Pampanga",
            "url": "https://pampanga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "zamboanga",
            "title": "Zamboanga",
            "url": "https://zamboanga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "russia", "title": "Russia"},
        "site": {
            "key": "moscow",
            "title": "\u041c\u043e\u0441\u043a\u0432\u0430",
            "url": "https://moscow.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "russia", "title": "Russia"},
        "site": {
            "key": "stpetersburg",
            "title": "\u0421. \u041f\u0435\u0442\u0435\u0440\u0431\u0443\u0440\u0433, Ru",
            "url": "https://stpetersburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "singapore", "title": "Singapore"},
        "site": {
            "key": "singapore",
            "title": "Singapore",
            "url": "https://singapore.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "korea", "title": "Korea"},
        "site": {"key": "seoul", "title": "Seoul", "url": "https://seoul.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "taiwan", "title": "Taiwan"},
        "site": {"key": "taipei", "title": "Taiwan", "url": "https://taipei.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "thailand", "title": "Thailand"},
        "site": {"key": "bangkok", "title": "Thailand", "url": "https://bangkok.craigslist.org/",},
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "turkey", "title": "Turkey"},
        "site": {
            "key": "istanbul",
            "title": "T\u00fcrkiye",
            "url": "https://istanbul.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "united_arab_emirates", "title": "United Arab Emirates"},
        "site": {
            "key": "dubai",
            "title": "United Arab Emirates",
            "url": "https://dubai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "asia", "title": "Asia"},
        "country": {"key": "vietnam", "title": "Vietnam"},
        "site": {"key": "vietnam", "title": "Vietnam", "url": "https://vietnam.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "austria", "title": "Austria"},
        "site": {"key": "vienna", "title": "Wien", "url": "https://vienna.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "belgium", "title": "Blegium"},
        "site": {"key": "brussels", "title": "Belgium", "url": "https://brussels.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "bulgaria", "title": "Bulgaria"},
        "site": {
            "key": "bulgaria",
            "title": "Bulgaria",
            "url": "https://bulgaria.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "croatia", "title": "Croatia"},
        "site": {"key": "zagreb", "title": "Croatia", "url": "https://zagreb.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "czech_republic", "title": "Czech Republic"},
        "site": {"key": "prague", "title": "Prague", "url": "https://prague.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "denmark", "title": "Denmark"},
        "site": {
            "key": "copenhagen",
            "title": "K\u00f8benhavn",
            "url": "https://copenhagen.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "finland", "title": "Finland"},
        "site": {
            "key": "helsinki",
            "title": "Suomi Ty\u00f6paikkoja,",
            "url": "https://helsinki.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "bordeaux",
            "title": "Bordeaux",
            "url": "https://bordeaux.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "cotedazur",
            "title": "Nice / C\u00f4te D'Azur",
            "url": "https://cotedazur.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "grenoble",
            "title": "Grenoble",
            "url": "https://grenoble.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {"key": "lille", "title": "Lille", "url": "https://lille.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "loire",
            "title": "Loire (Vall\u00e9e)",
            "url": "https://loire.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {"key": "lyon", "title": "Lyon", "url": "https://lyon.craigslist.org/"},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "marseilles",
            "title": "Marseille",
            "url": "https://marseilles.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "montpellier",
            "title": "Montpellier",
            "url": "https://montpellier.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {"key": "paris", "title": "Paris, FR", "url": "https://paris.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {"key": "rennes", "title": "Bretagne", "url": "https://rennes.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {"key": "rouen", "title": "Normandie", "url": "https://rouen.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "strasbourg",
            "title": "Strasbourg",
            "url": "https://strasbourg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "france", "title": "France"},
        "site": {
            "key": "toulouse",
            "title": "Toulouse",
            "url": "https://toulouse.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "berlin", "title": "Berlin", "url": "https://berlin.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "bremen", "title": "Bremen", "url": "https://bremen.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "cologne", "title": "K\u00f6ln", "url": "https://cologne.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "dresden", "title": "Dresden", "url": "https://dresden.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "dusseldorf",
            "title": "D\u00fcsseldorf",
            "url": "https://dusseldorf.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "essen", "title": "Essen / Ruhr", "url": "https://essen.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "frankfurt",
            "title": "Frankfurt",
            "url": "https://frankfurt.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "hamburg", "title": "Hamburg", "url": "https://hamburg.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "hannover",
            "title": "Hannover",
            "url": "https://hannover.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "heidelberg",
            "title": "Heidelberg",
            "url": "https://heidelberg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "kaiserslautern",
            "title": "Kaiserslautern",
            "url": "https://kaiserslautern.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {"key": "leipzig", "title": "Leipzig", "url": "https://leipzig.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "munich",
            "title": "M\u00fcnchen",
            "url": "https://munich.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "nuremberg",
            "title": "N\u00fcrnberg",
            "url": "https://nuremberg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "germany", "title": "Germany"},
        "site": {
            "key": "stuttgart",
            "title": "Stuttgart",
            "url": "https://stuttgart.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "greece", "title": "Greece"},
        "site": {"key": "athens", "title": "Greece", "url": "https://athens.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "hungary", "title": "Hungary"},
        "site": {
            "key": "budapest",
            "title": "Budapest",
            "url": "https://budapest.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "iceland", "title": "Iceland"},
        "site": {
            "key": "reykjavik",
            "title": "Reykjavik",
            "url": "https://reykjavik.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "ireland", "title": "Ireland"},
        "site": {"key": "dublin", "title": "Dublin, IE", "url": "https://dublin.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "bologna", "title": "Bologna", "url": "https://bologna.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {
            "key": "florence",
            "title": "Firenze / Toscana",
            "url": "https://florence.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "genoa", "title": "Genova", "url": "https://genoa.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "milan", "title": "Milano", "url": "https://milan.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {
            "key": "naples",
            "title": "Napoli / Campania",
            "url": "https://naples.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "perugia", "title": "Perugia", "url": "https://perugia.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "rome", "title": "Roma", "url": "https://rome.craigslist.org/"},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {
            "key": "sardinia",
            "title": "Sardegna",
            "url": "https://sardinia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "sicily", "title": "Sicilia", "url": "https://sicily.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {"key": "torino", "title": "Torino", "url": "https://torino.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "italy", "title": "Italy"},
        "site": {
            "key": "venice",
            "title": "Venezia / Veneto",
            "url": "https://venice.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "luxembourg", "title": "Luxembourg"},
        "site": {
            "key": "luxembourg",
            "title": "Luxembourg",
            "url": "https://luxembourg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "netherlands", "title": "Netherlands"},
        "site": {
            "key": "amsterdam",
            "title": "Amsterdam / Randstad",
            "url": "https://amsterdam.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "norway", "title": "Norway"},
        "site": {"key": "oslo", "title": "Norway", "url": "https://oslo.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "poland", "title": "Poland"},
        "site": {"key": "warsaw", "title": "Poland", "url": "https://warsaw.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "portugal", "title": "Portugal"},
        "site": {"key": "faro", "title": "Faro / Algarve", "url": "https://faro.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "portugal", "title": "Portugal"},
        "site": {"key": "lisbon", "title": "Lisboa", "url": "https://lisbon.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "portugal", "title": "Portugal"},
        "site": {"key": "porto", "title": "Porto", "url": "https://porto.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "romania", "title": "Romania"},
        "site": {
            "key": "bucharest",
            "title": "Romania",
            "url": "https://bucharest.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "russia", "title": "Russia"},
        "site": {
            "key": "moscow",
            "title": "\u041c\u043e\u0441\u043a\u0432\u0430",
            "url": "https://moscow.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "russia", "title": "Russia"},
        "site": {
            "key": "stpetersburg",
            "title": "\u0421. \u041f\u0435\u0442\u0435\u0440\u0431\u0443\u0440\u0433, Ru",
            "url": "https://stpetersburg.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {
            "key": "alicante",
            "title": "Alicante",
            "url": "https://alicante.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {
            "key": "baleares",
            "title": "Baleares",
            "url": "https://baleares.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {
            "key": "barcelona",
            "title": "Barcelona",
            "url": "https://barcelona.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "bilbao", "title": "Bilbao", "url": "https://bilbao.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "cadiz", "title": "C\u00e1diz", "url": "https://cadiz.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {
            "key": "canarias",
            "title": "Canarias",
            "url": "https://canarias.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "granada", "title": "Granada", "url": "https://granada.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "madrid", "title": "Madrid", "url": "https://madrid.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "malaga", "title": "M\u00e1laga", "url": "https://malaga.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {"key": "sevilla", "title": "Sevilla", "url": "https://sevilla.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "spain", "title": "Spain"},
        "site": {
            "key": "valencia",
            "title": "Valencia",
            "url": "https://valencia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "sweden", "title": "Sweden"},
        "site": {
            "key": "stockholm",
            "title": "Sverige",
            "url": "https://stockholm.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "switzerland", "title": "Switzerland"},
        "site": {"key": "basel", "title": "Basel", "url": "https://basel.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "switzerland", "title": "Switzerland"},
        "site": {"key": "bern", "title": "Bern", "url": "https://bern.craigslist.org/"},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "switzerland", "title": "Switzerland"},
        "site": {"key": "geneva", "title": "Gen\u00e8ve", "url": "https://geneva.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "switzerland", "title": "Switzerland"},
        "site": {
            "key": "lausanne",
            "title": "Lausanne",
            "url": "https://lausanne.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "switzerland", "title": "Switzerland"},
        "site": {"key": "zurich", "title": "Z\u00fcrich", "url": "https://zurich.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "turkey", "title": "Turkey"},
        "site": {
            "key": "istanbul",
            "title": "T\u00fcrkiye",
            "url": "https://istanbul.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "ukraine", "title": "Ukraine"},
        "site": {"key": "ukraine", "title": "Ukraine", "url": "https://ukraine.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "aberdeen",
            "title": "Aberdeen",
            "url": "https://aberdeen.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "bath", "title": "Bath, UK", "url": "https://bath.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "belfast", "title": "Belfast", "url": "https://belfast.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "birmingham",
            "title": "Birmingham / West Mids",
            "url": "https://birmingham.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "brighton",
            "title": "Brighton",
            "url": "https://brighton.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "bristol", "title": "Bristol", "url": "https://bristol.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "cambridge",
            "title": "Cambridge, UK",
            "url": "https://cambridge.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "cardiff",
            "title": "Cardiff / Wales",
            "url": "https://cardiff.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "coventry",
            "title": "Coventry, UK",
            "url": "https://coventry.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "derby", "title": "Derby, UK", "url": "https://derby.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "devon",
            "title": "Devon & Cornwall",
            "url": "https://devon.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "dundee", "title": "Dundee", "url": "https://dundee.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "eastmids",
            "title": "East Midlands",
            "url": "https://eastmids.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "edinburgh",
            "title": "Edinburgh",
            "url": "https://edinburgh.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "essex", "title": "Essex, UK", "url": "https://essex.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "glasgow", "title": "Glasgow", "url": "https://glasgow.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "hampshire",
            "title": "Hampshire",
            "url": "https://hampshire.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "kent", "title": "Kent, UK", "url": "https://kent.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "leeds", "title": "Leeds", "url": "https://leeds.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "liverpool",
            "title": "Liverpool",
            "url": "https://liverpool.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "london", "title": "London, UK", "url": "https://london.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "manchester",
            "title": "Manchester, UK",
            "url": "https://manchester.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "newcastle",
            "title": "Newcastle / Ne England",
            "url": "https://newcastle.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "norwich",
            "title": "East Anglia",
            "url": "https://norwich.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "nottingham",
            "title": "Nottingham, UK",
            "url": "https://nottingham.craigslist.org/",
        },
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {"key": "oxford", "title": "Oxford, UK", "url": "https://oxford.craigslist.org/",},
    },
    {
        "continent": {"key": "europe", "title": "Europe"},
        "country": {"key": "united_kingdom", "title": "United Kingdom"},
        "site": {
            "key": "sheffield",
            "title": "Sheffield",
            "url": "https://sheffield.craigslist.org/",
        },
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "egypt", "title": "Egypt"},
        "site": {"key": "cairo", "title": "Egypt", "url": "https://cairo.craigslist.org/",},
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "iraq", "title": "Iraq"},
        "site": {"key": "baghdad", "title": "Iraq", "url": "https://baghdad.craigslist.org/",},
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {"key": "haifa", "title": "Haifa", "url": "https://haifa.craigslist.org/",},
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {
            "key": "jerusalem",
            "title": "Jerusalem",
            "url": "https://jerusalem.craigslist.org/",
        },
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {
            "key": "ramallah",
            "title": "West Bank",
            "url": "https://ramallah.craigslist.org/",
        },
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "israel_and_palestine", "title": "Israel and Palestine"},
        "site": {"key": "telaviv", "title": "Tel Aviv", "url": "https://telaviv.craigslist.org/",},
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "kuwait", "title": "Kuwait"},
        "site": {"key": "kuwait", "title": "Kuwait", "url": "https://kuwait.craigslist.org/",},
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "lebanon", "title": "Lebanon"},
        "site": {
            "key": "beirut",
            "title": "Beirut, Lebanon",
            "url": "https://beirut.craigslist.org/",
        },
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "turkey", "title": "Turkey"},
        "site": {
            "key": "istanbul",
            "title": "T\u00fcrkiye",
            "url": "https://istanbul.craigslist.org/",
        },
    },
    {
        "continent": {"key": "middle east", "title": "Middle East"},
        "country": {"key": "united_arab_emirates", "title": "United Arab Emirates"},
        "site": {
            "key": "dubai",
            "title": "United Arab Emirates",
            "url": "https://dubai.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "adelaide",
            "title": "Adelaide, SA",
            "url": "https://adelaide.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "brisbane",
            "title": "Brisbane, QLD",
            "url": "https://brisbane.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "cairns", "title": "Cairns, QLD", "url": "https://cairns.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "canberra",
            "title": "Canberra, ACT",
            "url": "https://canberra.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "darwin", "title": "Darwin, NT", "url": "https://darwin.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "goldcoast",
            "title": "Gold Coast",
            "url": "https://goldcoast.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "hobart", "title": "Tasmania", "url": "https://hobart.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "melbourne",
            "title": "Melbourne, VIC",
            "url": "https://melbourne.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "ntl", "title": "Newcastle, NSW", "url": "https://ntl.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "perth", "title": "Perth, WA", "url": "https://perth.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {"key": "sydney", "title": "Sydney, NSW", "url": "https://sydney.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "australia", "title": "Australia"},
        "site": {
            "key": "wollongong",
            "title": "Wollongong, NSW",
            "url": "https://wollongong.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "guam_micronesia", "title": "Guam Micronesia"},
        "site": {
            "key": "micronesia",
            "title": "Guam-Micronesia",
            "url": "https://micronesia.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "new_zealand", "title": "New Zealand"},
        "site": {
            "key": "auckland",
            "title": "Auckland, NZ",
            "url": "https://auckland.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "new_zealand", "title": "New Zealand"},
        "site": {
            "key": "christchurch",
            "title": "Christchurch",
            "url": "https://christchurch.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "new_zealand", "title": "New Zealand"},
        "site": {
            "key": "dunedin",
            "title": "Dunedin, NZ",
            "url": "https://dunedin.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "new_zealand", "title": "New Zealand"},
        "site": {
            "key": "wellington",
            "title": "Wellington",
            "url": "https://wellington.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "bacolod", "title": "Bacolod", "url": "https://bacolod.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "cdo", "title": "Cagayan De Oro", "url": "https://cdo.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "cebu", "title": "Cebu", "url": "https://cebu.craigslist.org/"},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "davaocity",
            "title": "Davao City",
            "url": "https://davaocity.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "iloilo", "title": "Iloilo", "url": "https://iloilo.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "manila", "title": "Manila", "url": "https://manila.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {"key": "naga", "title": "Bicol Region", "url": "https://naga.craigslist.org/",},
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "pampanga",
            "title": "Pampanga",
            "url": "https://pampanga.craigslist.org/",
        },
    },
    {
        "continent": {"key": "oceania", "title": "Oceania"},
        "country": {"key": "philippines", "title": "Philippines"},
        "site": {
            "key": "zamboanga",
            "title": "Zamboanga",
            "url": "https://zamboanga.craigslist.org/",
        },
    },
)
